package org.dromara.ems.info.service;

import org.dromara.ems.info.domain.PowerEnergySupervisionChecklist;

import java.util.List;

/**
 * 动力能源部监督检查清单Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface IPowerEnergySupervisionChecklistService 
{
    /**
     * 查询动力能源部监督检查清单
     * 
     * @param id 动力能源部监督检查清单主键
     * @return 动力能源部监督检查清单
     */
    public PowerEnergySupervisionChecklist selectPowerEnergySupervisionChecklistById(Long id);

    /**
     * 查询动力能源部监督检查清单列表
     * 
     * @param powerEnergySupervisionChecklist 动力能源部监督检查清单
     * @return 动力能源部监督检查清单集合
     */
    public List<PowerEnergySupervisionChecklist> selectPowerEnergySupervisionChecklistList(PowerEnergySupervisionChecklist powerEnergySupervisionChecklist);

    /**
     * 新增动力能源部监督检查清单
     * 
     * @param powerEnergySupervisionChecklist 动力能源部监督检查清单
     * @return 结果
     */
    public int insertPowerEnergySupervisionChecklist(PowerEnergySupervisionChecklist powerEnergySupervisionChecklist);

    /**
     * 修改动力能源部监督检查清单
     * 
     * @param powerEnergySupervisionChecklist 动力能源部监督检查清单
     * @return 结果
     */
    public int updatePowerEnergySupervisionChecklist(PowerEnergySupervisionChecklist powerEnergySupervisionChecklist);

    /**
     * 批量删除动力能源部监督检查清单
     * 
     * @param ids 需要删除的动力能源部监督检查清单主键集合
     * @return 结果
     */
    public int deletePowerEnergySupervisionChecklistByIds(Long[] ids);

    /**
     * 删除动力能源部监督检查清单信息
     * 
     * @param id 动力能源部监督检查清单主键
     * @return 结果
     */
    public int deletePowerEnergySupervisionChecklistById(Long id);

    /**
     * 导入动力能源部监督检查清单数据
     *
     * @param recordList 记录数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importPowerEnergySupervisionChecklist(List<PowerEnergySupervisionChecklist> recordList, Boolean isUpdateSupport, String operName);
}
